==> igniteui-webcomponents-core-3.5.0.tgz: package/esm2015/lib/RippleDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { RippleDescription } from "./RippleDescription";
/**
 * @hidden
 */
export let RippleDescriptionMetadata = /*@__PURE__*/ (() => {
    class RippleDescriptionMetadata extends Base {
        static b(a) {
            if (RippleDescriptionMetadata.a == null) {
                RippleDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                RippleDescriptionMetadata.c(RippleDescriptionMetadata.a);
            }
            if (a.j(RippleDescriptionMetadata.a)) {
                return;
            }
            a.y(RippleDescriptionMetadata.a);
        }
        static c(a) {
            a.item("__qualifiedNameTS", "String:XRipple");
            a.item("EventSourceRef", "(w:EventSource,wf:EventSource)DataRef");
            a.item("RippleColor", "Brush");
            a.item("HoverColor", "Brush");
            a.item("ActualHoverColor", "Brush");
            a.item("ActualRippleColor", "Brush");
            a.item("RippleDuration", "Number:double");
            a.item("IsDisabled", "Boolean");
            a.item("IsCentered", "Boolean");
            a.item("IsHoverEnabled", "Boolean");
        }
        static d(a) {
            RippleDescriptionMetadata.b(a);
            a.aa("Ripple", () => new RippleDescription());
            a.z("Ripple", RippleDescriptionMetadata.a);
        }
    }
    RippleDescriptionMetadata.$t = /*@__PURE__*/ markType(RippleDescriptionMetadata, 'RippleDescriptionMetadata');
    RippleDescriptionMetadata.a = null;
    return RippleDescriptionMetadata;
})();

==> igniteui-webcomponents-core-4.2.5.tgz: package/esm2015/lib/RippleDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { RippleDescription } from "./RippleDescription";
/**
 * @hidden
 */
export let RippleDescriptionMetadata = /*@__PURE__*/ (() => {
    class RippleDescriptionMetadata extends Base {
        static b(a) {
            if (RippleDescriptionMetadata.a == null) {
                RippleDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                RippleDescriptionMetadata.c(RippleDescriptionMetadata.a);
            }
            if (a.k(RippleDescriptionMetadata.a)) {
                return;
            }
            a.aa(RippleDescriptionMetadata.a);
        }
        static c(a) {
            a.item("__qualifiedNameTS", "String:XRipple");
            a.item("EventSourceRef", "(w:EventSource,wf:EventSource)DataRef");
            a.item("RippleColor", "Brush");
            a.item("HoverColor", "Brush");
            a.item("ActualHoverColor", "Brush");
            a.item("ActualRippleColor", "Brush");
            a.item("RippleDuration", "Number:double");
            a.item("IsDisabled", "Boolean");
            a.item("IsCentered", "Boolean");
            a.item("IsHoverEnabled", "Boolean");
        }
        static d(a) {
            RippleDescriptionMetadata.b(a);
            a.ac("Ripple", () => new RippleDescription());
            a.ab("Ripple", RippleDescriptionMetadata.a);
        }
    }
    RippleDescriptionMetadata.$t = /*@__PURE__*/ markType(RippleDescriptionMetadata, 'RippleDescriptionMetadata');
    RippleDescriptionMetadata.a = null;
    return RippleDescriptionMetadata;
})();
